@@ -1,10 +1,5 @@
 package App::VivaldiUtils;
 
-our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-08-18'; # DATE
-our $DIST = 'App-VivaldiUtils'; # DIST
-our $VERSION = '0.008'; # VERSION
-
 use 5.010001;
 use strict 'subs', 'vars';
 use warnings;
@@ -12,6 +7,11 @@ use Log::ger;
 
 use App::BrowserUtils ();
 
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2022-07-24'; # DATE
+our $DIST = 'App-VivaldiUtils'; # DIST
+our $VERSION = '0.009'; # VERSION
+
 our %SPEC;
 
 $SPEC{':package'} = {
@@ -107,6 +107,7 @@ $SPEC{terminate_vivaldi} = {
     summary => "Terminate  (kill -KILL) Vivaldi",
     args => {
         %App::BrowserUtils::args_common,
+        %App::BrowserUtils::argopt_signal,
     },
 };
 sub terminate_vivaldi {
@@ -158,7 +159,7 @@ App::VivaldiUtils - Utilities related to the Vivaldi browser
 
 =head1 VERSION
 
-This document describes version 0.008 of App::VivaldiUtils (from Perl distribution App-VivaldiUtils), released on 2020-08-18.
+This document describes version 0.009 of App::VivaldiUtils (from Perl distribution App-VivaldiUtils), released on 2022-07-24.
 
 =head1 SYNOPSIS
 
@@ -199,17 +200,18 @@ This distribution includes several utilities related to the Vivaldi browser:
 
 Usage:
 
- pause_vivaldi(%args) -> [status, msg, payload, meta]
+ pause_vivaldi(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 Pause (kill -STOP) Vivaldi.
 
 A modern browser now runs complex web pages and applications. Despite browser's
 power management feature, these pages/tabs on the browser often still eat
-considerable CPU cycles even though they only run in the background. Stopping
+considerable CPU cycles even though they only run in the background. Pausing
 (kill -STOP) the browser processes is a simple and effective way to stop CPU
-eating on Unix. It can be performed whenever you are not using your browser for
-a little while, e.g. when you are typing on an editor or watching a movie. When
-you want to use your browser again, simply unpause it.
+eating on Unix and prolong your laptop battery life. It can be performed
+whenever you are not using your browser for a little while, e.g. when you are
+typing on an editor or watching a movie. When you want to use your browser
+again, simply unpause (kill -CONT) it.
 
 This function is not exported.
 
@@ -217,7 +219,7 @@ Arguments ('*' denotes required arguments):
 
 =over 4
 
-=item * B<users> => I<array[unix::local_uid]>
+=item * B<users> => I<array[unix::uid::exists]>
 
 Kill browser processes that belong to certain user(s) only.
 
@@ -226,12 +228,12 @@ Kill browser processes that belong to certain user(s) only.
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP-like status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (payload) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
 
 Return value:  (any)
 
@@ -241,7 +243,7 @@ Return value:  (any)
 
 Usage:
 
- ps_vivaldi(%args) -> [status, msg, payload, meta]
+ ps_vivaldi(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 List Vivaldi processes.
 
@@ -251,7 +253,7 @@ Arguments ('*' denotes required arguments):
 
 =over 4
 
-=item * B<users> => I<array[unix::local_uid]>
+=item * B<users> => I<array[unix::uid::exists]>
 
 Kill browser processes that belong to certain user(s) only.
 
@@ -260,12 +262,12 @@ Kill browser processes that belong to certain user(s) only.
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP-like status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (payload) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
 
 Return value:  (any)
 
@@ -275,7 +277,7 @@ Return value:  (any)
 
 Usage:
 
- restart_vivaldi(%args) -> [status, msg, payload, meta]
+ restart_vivaldi(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 Restart Vivaldi.
 
@@ -307,12 +309,12 @@ Pass -dry_run=E<gt>1 to enable simulation mode.
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP-like status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (payload) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
 
 Return value:  (any)
 
@@ -322,7 +324,7 @@ Return value:  (any)
 
 Usage:
 
- start_vivaldi(%args) -> [status, msg, payload, meta]
+ start_vivaldi(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 Start Vivaldi if not already started.
 
@@ -354,12 +356,12 @@ Pass -dry_run=E<gt>1 to enable simulation mode.
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP-like status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (payload) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
 
 Return value:  (any)
 
@@ -369,7 +371,7 @@ Return value:  (any)
 
 Usage:
 
- terminate_vivaldi(%args) -> [status, msg, payload, meta]
+ terminate_vivaldi(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 Terminate  (kill -KILL) Vivaldi.
 
@@ -379,7 +381,7 @@ Arguments ('*' denotes required arguments):
 
 =over 4
 
-=item * B<users> => I<array[unix::local_uid]>
+=item * B<users> => I<array[unix::uid::exists]>
 
 Kill browser processes that belong to certain user(s) only.
 
@@ -388,12 +390,12 @@ Kill browser processes that belong to certain user(s) only.
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP-like status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (payload) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
 
 Return value:  (any)
 
@@ -403,7 +405,7 @@ Return value:  (any)
 
 Usage:
 
- unpause_vivaldi(%args) -> [status, msg, payload, meta]
+ unpause_vivaldi(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 Unpause (resume, continue, kill -CONT) Vivaldi.
 
@@ -413,7 +415,7 @@ Arguments ('*' denotes required arguments):
 
 =over 4
 
-=item * B<users> => I<array[unix::local_uid]>
+=item * B<users> => I<array[unix::uid::exists]>
 
 Kill browser processes that belong to certain user(s) only.
 
@@ -422,12 +424,12 @@ Kill browser processes that belong to certain user(s) only.
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP-like status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (payload) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
 
 Return value:  (any)
 
@@ -437,7 +439,7 @@ Return value:  (any)
 
 Usage:
 
- vivaldi_has_processes(%args) -> [status, msg, payload, meta]
+ vivaldi_has_processes(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 Check whether Vivaldi has processes.
 
@@ -449,7 +451,7 @@ Arguments ('*' denotes required arguments):
 
 =item * B<quiet> => I<true>
 
-=item * B<users> => I<array[unix::local_uid]>
+=item * B<users> => I<array[unix::uid::exists]>
 
 Kill browser processes that belong to certain user(s) only.
 
@@ -458,12 +460,12 @@ Kill browser processes that belong to certain user(s) only.
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP-like status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (payload) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
 
 Return value:  (any)
 
@@ -473,7 +475,7 @@ Return value:  (any)
 
 Usage:
 
- vivaldi_is_paused(%args) -> [status, msg, payload, meta]
+ vivaldi_is_paused(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 Check whether Vivaldi is paused.
 
@@ -487,7 +489,7 @@ Arguments ('*' denotes required arguments):
 
 =item * B<quiet> => I<true>
 
-=item * B<users> => I<array[unix::local_uid]>
+=item * B<users> => I<array[unix::uid::exists]>
 
 Kill browser processes that belong to certain user(s) only.
 
@@ -496,12 +498,12 @@ Kill browser processes that belong to certain user(s) only.
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP-like status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (payload) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
 
 Return value:  (any)
 
@@ -511,7 +513,7 @@ Return value:  (any)
 
 Usage:
 
- vivaldi_is_running(%args) -> [status, msg, payload, meta]
+ vivaldi_is_running(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
 Check whether Vivaldi is running.
 
@@ -528,7 +530,7 @@ Arguments ('*' denotes required arguments):
 
 =item * B<quiet> => I<true>
 
-=item * B<users> => I<array[unix::local_uid]>
+=item * B<users> => I<array[unix::uid::exists]>
 
 Kill browser processes that belong to certain user(s) only.
 
@@ -537,12 +539,12 @@ Kill browser processes that belong to certain user(s) only.
 
 Returns an enveloped result (an array).
 
-First element (status) is an integer containing HTTP status code
+First element ($status_code) is an integer containing HTTP-like status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
-(msg) is a string containing error message, or 'OK' if status is
-200. Third element (payload) is optional, the actual result. Fourth
-element (meta) is called result metadata and is optional, a hash
-that contains extra information.
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
 
 Return value:  (any)
 
@@ -554,14 +556,6 @@ Please visit the project's homepage at L<https://metacpan.org/release/App-Vivald
 
 Source repository is at L<https://github.com/perlancar/perl-App-VivaldiUtils>.
 
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-VivaldiUtils>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
 =head1 SEE ALSO
 
 Some other CLI utilities related to Vivaldi: L<dump-vivaldi-history> (from
@@ -579,11 +573,36 @@ L<App::BrowserUtils>
 
 perlancar <perlancar@cpan.org>
 
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
+beyond that are considered a bug and can be reported to me.
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020, 2019 by perlancar@cpan.org.
+This software is copyright (c) 2022, 2020, 2019 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-VivaldiUtils>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =cut
